# -*- coding: utf-8 -*-
# Author: Franziska Horn <cod3licious@gmail.com>
# License: MIT

name = "autofeat"
__version__ = "1.1.3"
from .autofeat import AutoFeatModel, AutoFeatRegressor, AutoFeatClassifier  # noqa
from .featsel import FeatureSelector  # noqa
